@@ -26,6 +26,7 @@
 #include <ctype.h>
 #include <signal.h>
 #include <time.h>
+#include <unistd.h>
 
 #include "dominion.h"
 #include "cur_stuff.h"
@@ -336,7 +337,7 @@ void setup_armies(Snation *np)
   }
   np->n_armies = 10;
     /* figure out bonuses; crude formula for now */
-  np->combat_bonus = np->race.strength/4 + np->race.intel/12;
+  np->combat_bonus = np->race.strength/2.5 + np->race.intel/12.0;
   np->spy = 0;
   np->secrecy = 0;
 }
@@ -475,7 +476,7 @@ int setup_capital(Snation *np)
   distance = 7;
 
   while (x < 0) {
-    distance = max(1, --distance);
+    distance = dom_max_int(1, --distance);
     for (i = 0; i < 10; i++) {
       do {
 	  /* keep trying random sectors as long
@@ -924,13 +925,13 @@ void add_special_mag(Snation *np, char mag_ord[])
   strcpy(fname, MAG_PREFIX);
   strcat(fname, mag_ord);
   if ((magfp = fopen(fname, "r")) == NULL) {
-    fprintf(stderr,"Error: open file %s\n", fname);
+    fprintf(stderr,"Error opening file %s\n", fname);
     clean_exit();
     exit(1);
   }
   sprintf(fname, "exec/exec%d", np->id);
   if ((execfp = fopen(fname, "a")) == NULL) {
-    fprintf(stderr,"Error: open file %s\n", fname);
+    fprintf(stderr,"Error opening file %s\n", fname);
     clean_exit();
     exit(1);
   }
