@@ -98,11 +98,11 @@ void show_armies(Ssector *sp)
 
     /* cycle through armies and show them */
   alist = sp->alist;
-  n_shown = min(7, n_armies);
+  n_shown = dom_min_int(7, n_armies);
   if ((n_armies - current_index) <= n_shown/2) { /* are we near end of list */
     first_shown = n_armies - n_shown;
   } else {
-    first_shown = max(current_index-n_shown/2, 0);
+    first_shown = dom_max_int(current_index-n_shown/2, 0);
   }
   for (i = 0; i < n_shown; ++i) {
     ap = army_array[i+first_shown];
@@ -895,7 +895,7 @@ void draft_army(Snation *np)
 
   /* MDF - this SHOULD fix the problem with mages drafting for free */
   /* Since it is possible to have negative jewels, do this differently */
-  if (army_cost_jewels(&army) > max(0, user.np->jewels)) {
+  if (army_cost_jewels(&army) > dom_max_int(0, user.np->jewels)) {
     beep();
     statline2("space to go on", "not enough jewels to draft");
     get_space();
