@@ -228,8 +228,7 @@ void delete_army_nation(Snation *np, Sarmy *ap)
     /* see if the army to be deleted is the head of the list */
   if ((alist->owner == ap->owner) && (alist->id == ap->id)) {
       /* in this special case, copy the second army to
-	 the first, then free up the second.
-       */
+	 the first, then free up the second. */
     tmp = alist->next;		/* the next one must be saved for freeing */
     if (alist->next != NULL) {
       *alist = *(alist->next);
@@ -420,7 +419,7 @@ int can_occupy(Sarmy *ap)
 
 int can_patrol(Sarmy *ap)
 {
-  if (ap->n_soldiers >= OCCUPYING_SOLDIERS/2) {
+  if (ap->n_soldiers >= OCCUPYING_SOLDIERS/2 && !is_in_transport(ap)) {
     return 1;
   } else {
     return 0;
@@ -429,7 +428,7 @@ int can_patrol(Sarmy *ap)
 
 int can_intercept(Sarmy *ap)
 {
-  if (ap->n_soldiers >= OCCUPYING_SOLDIERS/2) {
+  if (ap->n_soldiers >= OCCUPYING_SOLDIERS/2 && !is_in_transport(ap) ) {
     return 1;
   } else {
     return 0;
@@ -438,7 +437,11 @@ int can_intercept(Sarmy *ap)
 
 int can_garrison(Sarmy *ap)
 {
-  return 1;
+  if ( !is_in_transport(ap)) {
+    return 1;
+  } else {
+  return 0;
+  }
 }
 
   /* loads army types from the army types file */
