@@ -94,7 +94,6 @@ void dobattles()
 
   printf("Moving intercepts...\n"); fflush(stdout);
   move_intercepts(dm);
-
   printf("Doing battles...\n"); fflush(stdout);
   for (x = 0; x < world.xmax; x++) {
     for (y = 0; y < world.ymax; y++) {
@@ -118,59 +117,93 @@ void dobattles()
   }
   free_diplo(dm, world.n_nations);
 }
-
 /*
   takes all armies in intercept mode and sees if it can move them to
   attack an enemy army. (I should check this over. --MDF)
 */
 void move_intercepts(Sdiplo **dm)
 {
-  int nation,x,y;
+  struct position {
+    int x,y,value; 
+    };
+  struct position pos;
+  int nation,x,y,value;
   Snation *np;
   Ssector *sp;
   Sarmy *ap;
-
+  
+  pos.x=0;pos.y=0;pos.value=0;
   for (nation = 1; nation < world.n_nations; nation++) {
     np = &world.nations[nation];
     ap = np->armies;
     while (ap != NULL) {
       if (ap->status == A_INTERCEPT) {
-	for (x = ap->pos.x - 1; x <= ap->pos.x + 1; x++) {
-	  for (y = ap->pos.y - 1; y <= ap->pos.y + 1; y++) {
-	    sp = &world.map[(*wrapx)(x,y)][(*wrapy)(x,y)];
-	      /* army might not be in intercept mode any more,
-		 in which case we don't make it move.  that way
-		 an intercept army will only move once.
-	       */
-	    if (ap->status == A_INTERCEPT && against(dm, sp->alist, ap)
-		&& (good_army_altitude(np, sp, ap) || is_kamikaze(ap))) {
-/*	      printf("%s army %d is intercepting from (%d,%d) to (%d,%d)\n",
-		     np->name, ap->id, ap->pos.x, ap->pos.y, x, y); */
-	      ap->status = A_ATTACK;
-	      delete_army_sector(&world.map[ap->pos.x][ap->pos.y],ap);
-	      ap->pos.x = (*wrapx)(x,y);
-	      ap->pos.y = (*wrapy)(x,y);
-	      insert_army_sector(sp, ap);
+/* 1st check sector army is in.  If there a force large enough to occupy here 
+   then change status to attack and leave army here. */
+	sp = &world.map[(*wrapx)(ap->pos.x,ap->pos.y)]
+	  [(*wrapy)(ap->pos.x,ap->pos.y)];
+	if (ap->status == A_INTERCEPT && (against(dm, sp->alist, ap) == 2)
+                && (good_army_altitude(np, sp, ap) || is_kamikaze(ap))) {
+          printf("%s army %d is intercepting but not moving\n",
+                     np->name, ap->id); 
+	  ap->status = A_ATTACK;
+	}
+	else {
+/* 2nd loop through surrounding sectors and find sector with highest intercept
+   value based on return from against and +1 if sector is owned 
+   by intercepting army's nation.  Uses first sector it finds with highest
+   value. */
+	  pos.value=0;pos.x=0;pos.y=0;
+	  for (x = ap->pos.x - 1; x <= ap->pos.x + 1; x++) {
+	    for (y = ap->pos.y - 1; y <= ap->pos.y + 1; y++) {
+	      sp = &world.map[(*wrapx)(x,y)][(*wrapy)(x,y)];
+/*	      if (ap->status == A_INTERCEPT && against(dm, sp->alist, ap)
+		&& (good_army_altitude(np, sp, ap) || is_kamikaze(ap))) { */
+	      value = against(dm,sp->alist,ap);
+	      if (( value > 0 ) && ( sp->owner == ap->owner))
+		value=value+ 2;
+	      if (value > pos.value) {
+		pos.value = value;
+		pos.x = x;
+		pos.y = y;
+	      }
 	    }
 	  }
 	}
+/* if pos.value is >0 then intercept to that sector */
+	if (pos.value > 0 ) {
+	  ap->status = A_ATTACK;
+	  delete_army_sector(&world.map[ap->pos.x][ap->pos.y],ap);
+	  ap->pos.x = (*wrapx)(pos.x,pos.y);
+	  ap->pos.y = (*wrapy)(pos.x,pos.y);
+	  sp = &world.map[(*wrapx)(pos.x,pos.y)][(*wrapy)(pos.x,pos.y)];
+	  insert_army_sector(sp, ap);
+          printf("%s army %d is intercepting from (%d,%d) to (%d,%d)\n",
+		     np->name, ap->id, ap->pos.x, ap->pos.y, x, y); }
+
       }
       ap = ap->next;
     }
   }
+
 }
 
 
 /*
   against(): searches through a list of armies (a sector army list) and
   checks if any are at war/jihad with given army. Used for moving intercepts.
+  Returns 2 if there is an enemy army >= OCCUPYING_SOLDIERS
+  Returns 1 if there is an enemy army < OCCUPYING_SOLDIERS
+  Returns the highest value for all the armies in the sector.
 */
 int against(Sdiplo **dm, struct armyid *list, Sarmy *intercept)
 {
   struct armyid *tmp;
   Sarmy *ap, *get_army ();	/* Also check if you can see the army... */
   Snation * np;
+  int value;
   
+  value = 0;
   tmp = list;
   while (tmp != NULL) {
     if (are_enemies(dm, tmp->owner, intercept->owner)) {
@@ -180,12 +213,18 @@ int against(Sdiplo **dm, struct armyid *list, Sarmy *intercept)
 	;
       }
       else {
-	return 1;
-      }
+	 if (ap->n_soldiers >= OCCUPYING_SOLDIERS) {
+	   value = 2;
+	 }
+	 else {
+	   if (value < 2)
+	     value = 1;
+	 }
+       }
     }
     tmp = tmp->next;
   }
-  return 0;
+  return value;
 }
 
 
@@ -569,8 +608,8 @@ int old_calc_casualty(army1, army2)
 
   /* Determine which army is larger. */
 
-  larger_army = max(army1, army2);
-  smaller_army = min(army1, army2);
+  larger_army = dom_max_int(army1, army2);
+  smaller_army = dom_min_int(army1, army2);
 
   /* Calculate forces and army difference. */
 
@@ -586,7 +625,7 @@ int old_calc_casualty(army1, army2)
   smaller_casualties = (int) ( (float) larger_force / (float) smaller_force *
 			       (float) larger_casualties );
 
-  if (max(army1, army2) == army1) {
+  if (dom_max_int(army1, army2) == army1) {
     return larger_casualties;
   } else {
     return smaller_casualties;
@@ -610,8 +649,8 @@ int calc_casualty(int army1, int army2, double death_ratio)
 
   /* Determine which army is larger. */
 
-  larger_army = max(army1, army2);
-  smaller_army = min(army1, army2);
+  larger_army = dom_max_int(army1, army2);
+  smaller_army = dom_min_int(army1, army2);
 
 /* 
   Calculate the ratio of forces lost, related to the sqare of the
@@ -619,7 +658,7 @@ int calc_casualty(int army1, int army2, double death_ratio)
 */
    
   casualty_ratio = (double)smaller_army/(double)larger_army;
-  if ((casualty_ratio < death_ratio) && (max(army1,army2) == army2)) {
+  if ((casualty_ratio < death_ratio) && (dom_max_int(army1,army2) == army2)) {
   /* If it's an automatic victory situation */
     return smaller_army;
   }
@@ -687,7 +726,7 @@ int calc_casualty(int army1, int army2, double death_ratio)
   smaller_casualties += extra_small;
   larger_casualties += extra_large;
 
-  if (max(army1, army2) == army1) {
+  if (dom_max_int(army1, army2) == army1) {
     return larger_casualties;
   } else {
     return smaller_casualties;
@@ -915,6 +954,7 @@ void extract_losses(struct army_info *head, Ssector *sp)
   extern Sh_spell *is_spelled();
   Sarmy *ap, *ap2;
   int total_dead = 0;
+  int total_nonvamp = 0;
   int n_vampires = 0;
   int revived;
 
@@ -925,6 +965,10 @@ void extract_losses(struct army_info *head, Ssector *sp)
     ap->n_soldiers -= list->casualty;    
     total_dead += list->casualty;
     if (is_vampire(ap)) { n_vampires++; }
+      else {
+	if (!is_kamikaze(ap))
+	   total_nonvamp += list->casualty;
+      }
     if (ap->n_soldiers == 0) {	/* bye bye */
       if (is_cargo(ap) && ap->cargo.army > -1) { /* dead transport has army */
 	ap2 = get_army(np, ap->cargo.army);
@@ -952,8 +996,9 @@ void extract_losses(struct army_info *head, Ssector *sp)
     ap = get_army(np, list->armyid->id);
     if (ap && is_uncontrolled(ap)) { continue; }
     if (ap && is_vampire(ap)) {
-      revived = min((int)(total_dead * VAMPIRE_FRACT), 10 * ap->n_soldiers);
-      revived = min(revived, total_dead / n_vampires);
+      revived = dom_min_int((int)(total_nonvamp * VAMPIRE_FRACT),
+			    3 * ap->n_soldiers);
+      revived = dom_min_int(revived, total_nonvamp / n_vampires);
       sprintf(fname, "mail%d", ap->owner);
       fp = fopen(fname, "a");
       if (!fp) {
