@@ -22,6 +22,7 @@
 
 #include <stdio.h>
 #include <ctype.h>
+#include <unistd.h>
 
 #include "dominion.h"
 #include "news.h"
@@ -524,14 +525,14 @@ Sgroup *news_groups_menu(int human, int reading)
 	(g_temp)->last=last_in;
 	(g_temp)->postable=post_in;
 	(g_temp)->next=NULL;
-	if ((human==0)||(g_temp->postable=='1'))
-	  if (!reading||((g_temp->first)<=(g_temp->last)))
-	  {
+	if ((human==0)||(g_temp->postable=='1')) {
+	  if (!reading||((g_temp->first)<=(g_temp->last))) {
 	    group_insert(&g_first, g_temp);
 	    total_groups++;
 	  }
-	else
+	} else {
 	  free(g_temp);
+	}
       }
   if (g_fp != NULL) { fclose(g_fp); } 
   clear();
