@@ -54,8 +54,9 @@ void find_desire(Snation *np, struct desire **des_array);
 void cmd_astat(Snation *np, struct argument args[]);
 
 
-#define NSTATS 2		/* different statuses to move */
+#define NSTATS 4		/* different statuses to move */
 #define CN_PATROL		/* comment out to keep cns from patrolling */
+#define CN_INTER                /* comment out to keep cns from intercepting */
 
 extern Sworld world;
 extern Suser user;
@@ -67,7 +68,7 @@ extern struct army_type *army_types;
 extern struct spirit_type *spirit_types;
 
 
-int statary[NSTATS] = { A_ATTACK|A_DEFEND, A_PATROL };
+int statary[NSTATS] = { A_ATTACK,A_DEFEND, A_PATROL, A_INTERCEPT };
 float cn_food_need,cn_metal_need,cn_jewel_need,cn_money_need;
 int opt_army_size,atwar,cn_specific;
 
@@ -79,6 +80,7 @@ void cn_moves(Snation *np)
   int i;
   struct desire **des_array;
 
+
   des_array = (struct desire **) malloc(world.xmax*sizeof(struct desire*));
   for (i = 0; i < world.xmax; ++i)
     des_array[i] = (struct desire *) malloc(world.ymax*sizeof(struct desire));
@@ -191,7 +193,7 @@ cn_jewel_need =(float)calc_expend_jewels(np)/((float)calc_jewels(np)+1.0)+.3;*/
   if (debug >= 2) printf("food need = %f\n",cn_food_need);
   if(atwar){
     opt_army_size = get_n_soldiers (np) * np->cn_params->army_size /
-		    (np->n_sects * 25);
+		    (np->n_sects * 10);
     opt_army_size = max (np->cn_params->min_size, opt_army_size);
   }
   else{
@@ -203,26 +205,58 @@ cn_jewel_need =(float)calc_expend_jewels(np)/((float)calc_jewels(np)+1.0)+.3;*/
 
 		/*----  Handle the CN's Economy ----*/
   if(atwar){
-    np->taxes = 25;
-    np->tech_r_d_metal = 0;
-    if (next_thon_jewels(np) < MAGE_JEWELS_MAINT) {
+    np->taxes = 15;
+    np->spy_r_d = 0;
+    if (calc_metal(np) < 30000 ) {
+      np->tech_r_d_metal = 0;
+      np->tech_r_d = 15;
+    }
+    else {
+      np->tech_r_d_metal = 15;
+      np->tech_r_d = 0;
+    }
+    if ( (calc_jewels(np) - MAGE_JEWELS_MAINT) < 0 ) {
       np->mag_r_d_jewels = 0;
     } else {
-      if (calc_jewels(np) * 2 > np->jewels) {
-	np->mag_r_d_jewels = np->jewels * 50 / calc_jewels(np);
+      if (next_thon_jewels(np) < INITIATION_JEWELS * 2) {
+	/* stockpile jewels fast */
+	np->mag_r_d_jewels = (((calc_jewels(np) - MAGE_JEWELS_MAINT - 
+	   INITIATION_JEWELS*2) * 100 )/calc_jewels(np));
       } else {
-	np->mag_r_d_jewels = 100;
+	/* stockpile jewels slow */
+	np->mag_r_d_jewels = (((calc_jewels(np) - MAGE_JEWELS_MAINT - 
+	   INITIATION_JEWELS / 5) *100 )/calc_jewels(np));
       }
     }
-    np->mag_r_d = 15;
-    np->tech_r_d = 15;
+    if ( np->mag_r_d_jewels > 0 ) {
+      np->mag_r_d = 0;
+    } else {
+      np->mag_r_d = 15;
+    }
   } else {
-    np->taxes = 15;
-    np->tech_r_d_metal = 30;
-    np->mag_r_d_jewels = 10;
-    np->mag_r_d = 25;
-    np->tech_r_d = 25;
-  }
+    np->taxes = 13;
+    if (calc_metal(np) < 10000 ) {
+      np->tech_r_d_metal = 30;
+    } else {
+	np->tech_r_d_metal = 75;
+    }
+    if (((calc_jewels(np) < INITIATION_JEWELS) && (next_thon_jewels(np) 
+      < INITIATION_JEWELS * 2)) || (calc_jewels(np) == 0)) {
+      np->mag_r_d_jewels = 0;
+    } else {
+      np->mag_r_d_jewels = (((calc_jewels(np) - INITIATION_JEWELS / 5 ) 
+      * 100)/calc_jewels(np)) ;
+      if (np->mag_r_d_jewels < 0) 
+	np->mag_r_d_jewels = 0;
+    }
+    if (np->mag_r_d_jewels == 0) {
+      np->mag_r_d = 15;
+    } else {
+      np->mag_r_d = 0;
+    }
+    np->tech_r_d = 10;
+    np->spy_r_d = 10;
+    }
 }
 
 /*---------------------------do_cn_draft()-----------------------------------
@@ -239,7 +273,7 @@ void do_cn_draft(Snation *np)
     int force, m_cost, s_cost;
     } a_info[MAX_TYPES];
 
-  int max_sold,ngood,good_armies[MAX_TYPES],i,tmp,patrol_sold;
+  int max_sold,ngood,good_armies[MAX_TYPES],i,tmp,patrol_sold,inter_sold;
   int to_draft, ndraft, indx, f_max, cur_sold;
   char type[NAMELEN];
 
@@ -252,6 +286,7 @@ void do_cn_draft(Snation *np)
   if (cur_sold >= max_sold)
     return;
   patrol_sold = count_troops_with(np, A_PATROL);
+  inter_sold = count_troops_with(np, A_INTERCEPT);
   if (debug >= 2) printf("pat %d tot %d:",patrol_sold, cur_sold);
 
   tmp = tmp * (np->race.repro - np->race.mortality) / 100;
@@ -297,14 +332,26 @@ void do_cn_draft(Snation *np)
     this_atype = army_types[good_armies[indx]];
     strcpy(type,this_atype.type);
 #ifdef CN_PATROL
-    if ( atwar && (patrol_sold < cur_sold * np->cn_params->pat / 100)){
+    if (( atwar && (patrol_sold < cur_sold * np->cn_params->pat / 100)) || 
+	(!atwar && (patrol_sold < cur_sold * np->cn_params->pat / 200)
+	 && (world.turn > 5))) {
       army = make_army(type,type, opt_army_size, A_PATROL, np->id, sp->loc);
       patrol_sold += opt_army_size;
       if (debug >= 2) printf("patrol ");
       }
     else 
 #endif
-        army = make_army(type,type, opt_army_size, A_DEFEND, np->id, sp->loc);
+#ifdef CN_INTER
+    if (( atwar && (inter_sold < cur_sold * np->cn_params->pat / 100)) ||
+      	(!atwar && (inter_sold < cur_sold * np->cn_params->pat / 200)
+	 && (world.turn > 5) )) {
+      army = make_army(type,type, opt_army_size, A_INTERCEPT, np->id, sp->loc);
+      inter_sold += opt_army_size;
+      if (debug >= 2) printf("intercept ");
+      }
+    else 
+#endif
+      army = make_army(type,type, opt_army_size, A_DEFEND, np->id, sp->loc);
     cn_draft_army(army, np, sp);
     
     if (debug >= 2)		/* print message about what happened */
@@ -407,6 +454,8 @@ void do_cn_summon(Snation *np)
     }
     insert_army_sector(sp, &army);
     np->spell_pts -= spirit_types[sindex].spell_pts_draft;
+/*    printf("summon cost %d\n",spirit_types[sindex].spell_pts_draft);
+    printf("net points %d\n",net_points); */
     net_points = new_spell_pts(np) - military_maint_spell_pts(np);
   }
 }
@@ -438,15 +487,19 @@ void do_cn_merge(Snation *np)
   }
 
   for(ap = np->armies ;ap ;ap = ap->next){	/* for all cns armies */
+    printf("%s -- 0x%08lx\n", np->name, (unsigned long) ap);
+    printf("%s -- 0x%08lx  %d\n", np->name, (unsigned long) ap, ap->id);
     i = max (opt_army_size * np->cn_params->merge_size_pct / 100,
 	     OCCUPYING_SOLDIERS);
+    printf("%s -- 0x%08lx  %d\n", np->name, (unsigned long) ap, ap->id);
     if((ap->n_soldiers >= i) &&
 	(!atwar || (ap->n_soldiers * (ap->sp_bonus + 100) / 100 >= i)))
       continue;					/* skip loop if army ok. */
-    if((ap->status == A_PATROL) &&
-	(ap->n_soldiers >= min(OCCUPYING_SOLDIERS,
-			       i * np->cn_params->pat_size_pct / 100)))
+    if ((ap->status == A_PATROL) &&
+	(ap->n_soldiers >= dom_min_int(OCCUPYING_SOLDIERS,
+			       i * np->cn_params->pat_size_pct / 100))) {
       continue;					/* skip loop if army ok. */
+    }
     if(is_mage(ap))
       continue;
     bestarmy = 0;
@@ -480,9 +533,10 @@ void do_cn_merge(Snation *np)
     }		/* for x */
 
   /* now move the army to the correct location and merge.  */
-    if(bestarmy){
-      if (debug >= 2)
+    if (bestarmy && (bestarmy->id != ap->id)){
+      if (debug >= 2) {
         printf("cn army %d merges with %d.\n",ap->id,bestarmy->id);
+      }
       args[1].data.num = ap->id;
       alist = world.map[(*wrapx)(x,y)][(*wrapy)(x,y)].alist;
       args[2].data.num = (*wrapx)(finalpos.x,finalpos.y);
@@ -491,8 +545,12 @@ void do_cn_merge(Snation *np)
       cmd_amove(np,args);		/* move army to new location */
       args[1].data.num = ap->id;
       args[2].data.num = bestarmy->id;
+      printf("%s -- 0x%08lx about to cmd_amerge\n", np->name, (unsigned long) ap);
+      printf("%s -- 0x%08lx  %d about to cmd_amerge\n", np->name, (unsigned long) ap, ap->id);
       cmd_amerge(np,args);
     }
+    printf("%s -- 0x%08lx end of ap loop\n", np->name, (unsigned long) ap);
+    printf("%s -- 0x%08lx  %d end of ap loop\n", np->name, (unsigned long) ap, ap->id);
   }		/* for ap */
 }
 
@@ -509,7 +567,7 @@ void do_cn_split(Snation *np)
   int patrol_size;
 
   for(ap = np->armies ;ap ;ap = ap->next){	/* for all cns armies */
-    if (ap->status != A_PATROL){
+    if (ap->status != A_PATROL) {
       if ((ap->n_soldiers < opt_army_size * 2) || is_spirit(ap))
         continue;				/* skip loop if small army */
       if (atwar &&
@@ -523,7 +581,10 @@ void do_cn_split(Snation *np)
         cmd_asplit(np,args);
       }
     } else {			/*--- this is a patrol army, can be small ---*/
-      patrol_size = min(OCCUPYING_SOLDIERS, 
+      if (!atwar)
+	patrol_size = OCCUPYING_SOLDIERS/2;
+      else
+	patrol_size = dom_max_int(OCCUPYING_SOLDIERS/2, 
 			opt_army_size * np->cn_params->pat_size_pct / 100);
       if ((ap->n_soldiers < patrol_size * 2) || is_spirit(ap))
         continue;				/* skip loop if small army */
@@ -555,8 +616,8 @@ void do_cn_armies(Snation *np, struct desire **des_array)
   struct argument args[N_EXEC_ARGS];
   struct tmp_map legal_moves[CN_SIDE][CN_SIDE];
 
-  find_desire(np,des_array);			/* fill desireability array */
-  for(i = 0;i < CN_SIDE; i++){			/* fill in border of legal mv */
+  find_desire(np,des_array);		       /* fill desireability array */
+  for(i = 0;i < CN_SIDE; i++){		       /* fill in border of legal mv */
     legal_moves[0][i].mvleft = -2;
     legal_moves[CN_SIDE-1][i].mvleft = -2;
     legal_moves[i][0].mvleft = -2;
@@ -571,8 +632,8 @@ void do_cn_armies(Snation *np, struct desire **des_array)
 		/*--- now move defends(occupys) and patrols ---*/
   for (statidx = 0; statidx < NSTATS; statidx++) {
     for (ap = np->armies; ap; ap = ap->next) {
-      if ((ap->status & statary[statidx]) == 0)	/* bad status */
-	continue;
+      if (ap->status != statary[statidx]) /* bad status */
+	continue; 
       if(is_mage(ap) && ap->n_soldiers == 1)
         continue;
       if ( is_cargo(ap) || is_in_transport(ap) || is_uncontrolled(ap))
@@ -590,7 +651,16 @@ void do_cn_armies(Snation *np, struct desire **des_array)
           if (good_altitude(&world.map[(*wrapx)(x,y)][(*wrapy)(x,y)],np) &&
 	        ((ap->status & (A_DEFEND|A_ATTACK)) ||
 		(world.map[(*wrapx)(x,y)][(*wrapy)(x,y)].owner == np->id))) {
-	    des_here = des_array[(*wrapx)(x,y)][(*wrapy)(x,y)].final;
+	    switch (ap->status) {	    
+	      case A_PATROL:
+	        des_here = des_array[(*wrapx)(x,y)][(*wrapy)(x,y)].patrol;
+		break;
+	      case A_INTERCEPT:
+	        des_here = des_array[(*wrapx)(x,y)][(*wrapy)(x,y)].inter;
+		break;
+	      default:
+		des_here = des_array[(*wrapx)(x,y)][(*wrapy)(x,y)].final;
+	      }
 	    tx = x - ap->pos.x + CN_VIEW + 1;
 	    ty = y - ap->pos.y + CN_VIEW + 1;
 	    if (legal_moves[tx][ty].mvleft >= 0){
@@ -626,7 +696,7 @@ void do_cn_armies(Snation *np, struct desire **des_array)
       args[3].data.num = y;
       args[4].data.num = legal_moves[tx][ty].mvleft;
       cmd_amove(np,args);		/* move army to new location */
-      if (debug >= 2) {
+      if (debug >= 2) { 
 	printf ("moving to desire value %d\n",des_array[x][y].final);
       }
       switch (ap->status){
@@ -644,12 +714,26 @@ void do_cn_armies(Snation *np, struct desire **des_array)
             (opt_army_size+ap->n_soldiers);
 	  break;
 	case A_PATROL:
+	  for (tx = x-2; tx <= x+2; tx++)
+	    for (ty = y - 2; ty <= y+2; ty++)
+	      if ((tx == x-2)||(tx == x+2)||(ty == y-2)||(ty == y+2))	
+		  des_array[(*wrapx)(tx,ty)][(*wrapy)(tx,ty)].patrol =
+		    des_array[(*wrapx)(tx,ty)][(*wrapy)(tx,ty)].patrol/2;
+	      else
+		  des_array[(*wrapx)(tx,ty)][(*wrapy)(tx,ty)].patrol = 0;
+	  des_array[(*wrapx)(tx,ty)][(*wrapy)(x,y)].inter = 
+	    des_array[(*wrapx)(tx,ty)][(*wrapy)(x,y)].inter/2;
+	  break;
+	case A_INTERCEPT:
 	  for (tx = x-1; tx <= x+1; tx++)
 	    for (ty = y - 1; ty <= y+1; ty++)
-	      des_array[(*wrapx)(tx,ty)][(*wrapy)(tx,ty)].final = 0;
+	      des_array[(*wrapx)(tx,ty)][(*wrapy)(tx,ty)].inter = 0;
+	  des_array[(*wrapx)(tx,ty)][(*wrapy)(x,y)].patrol = 
+	    des_array[(*wrapx)(tx,ty)][(*wrapy)(x,y)].patrol/2;
 	  break;
 	default:
 	  break;
+
       }
     }
   }
@@ -667,7 +751,8 @@ and never more than the number needed to produce enough food.
 
 Step 2:
 	Sectors with no designation are designated, with preference to metal
-mines and jewel mines.
+mines and jewel mines. Sectors are only designated to farms if food_need > .85
+if food_need is not > 1.1 then sectors of soil < 3 will not be used.
 -----------------------------------------------------------------------------*/
 void do_cn_redesig(Snation *np)
 {
@@ -739,9 +824,9 @@ void do_cn_redesig(Snation *np)
   for (Loop = 0; (Loop < np->n_sects) && (np->money > 0); Loop++) {
     x = Pointer->pt.x;
     y = Pointer->pt.y;
-    if (world.map[x][y].n_people > 0 &&
-	world.map[x][y].designation == D_NODESIG) {
-      if (world.map[x][y].metal + world.map[x][y].jewels > 0){
+    if ((world.map[x][y].n_people > 0 || world.turn < 3) &&
+	world.map[x][y].designation == D_NODESIG)  {
+      if (world.map[x][y].metal + world.map[x][y].jewels > 0 ){
 	if (world.map[x][y].metal >= world.map[x][y].jewels) {
 	  world.map[x][y].designation = D_METAL_MINE;
 	  np->money -= desig_map[D_METAL_MINE].price;
@@ -750,12 +835,15 @@ void do_cn_redesig(Snation *np)
 	  np->money -= desig_map[D_JEWEL_MINE].price;
 	}
       } else {
-	if (world.map[x][y].soil > 0) {
-	  world.map[x][y].designation = D_FARM;
-	  np->money -= desig_map[D_FARM].price;
+	if ((world.map[x][y].soil > 0) && (cn_food_need > .85 )) {
+	  if (cn_food_need > 1.1 || world.map[x][y].soil > 3 ) {
+	    world.map[x][y].designation = D_FARM;
+ 	    np->money -= desig_map[D_FARM].price; }
 	}
       }
     }
   Pointer = Pointer->next;
   }
 }
+
+
