@@ -1,6 +1,3 @@
-#ifndef _CN_H
-#define _CN_H
-
 typedef struct comp_params {
   int hos;			/* percent chance of lowering status */
   int dip_chan;			/* percent chance of changing status */
@@ -18,7 +15,5 @@ struct tmp_map{
   int mvcost,mvleft;
 };
 struct desire{
-  int base,final;
+  int base,final,patrol,inter;
 };
-
-#endif /* _CN_H */
