@@ -25,6 +25,7 @@
 #include <stdio.h>
 #include <ctype.h>
 #include <signal.h>
+#include <assert.h>
 
 #include "config.h"
 #include "dominion.h"
@@ -134,7 +135,7 @@ int tmp_army_better(Sarmy *ap, Sarmy *tmpap, Sarmy *oldap)
 	Fill the desire array with the desireability for each sector on the
 map.  The base desire goes from zero to half the length of the shortest side.
 To find the final desire, the base desire is squared.  The desire for the
-surrounding sectors is modified.  If the base desire is N, then all the
+surrounding sectors is modified.  If the base desireOA is N, then all the
 adjacent sectors have their desireability increased by N-1, the next sectors
 out are increased by N-2, etc.  This will hopefully keep cn's moving in the
 right general direction. (the base desire of owned sectors is 0, unless at war)
@@ -146,7 +147,7 @@ void find_desire(Snation *np, struct desire **des_array)
   unowned = count_unowned_sectors(np);
   mine = np->n_sects;
   enemy = count_enemy_sectors(np) * 2;	/* over-estimate enemy */
-  smax = max(mine,max(enemy,unowned));
+  smax = dom_max_int(mine, dom_max_int(enemy,unowned));
 
   for(x = 0; x < world.xmax;x++)
     for(y = 0; y < world.ymax; y++){
@@ -164,6 +165,12 @@ void find_desire(Snation *np, struct desire **des_array)
             des_array[x][y].final *= 2;
 	    }
         }
+      if (world.map[x][y].owner == np->id ) {
+	des_array[x][y].inter = des_array[x][y].patrol 
+	  = world.map[x][y].n_people/25;
+      }
+      else
+	des_array[x][y].inter = des_array[x][y].patrol = 0;
       if(user.visible_sectors[x][y])
         for(i = 1;i < d && add_square(x,y,i,d-i,des_array,np);i++);
       }
@@ -379,17 +386,21 @@ void check_moves(Snation *np, Sarmy *ap, struct tmp_map ary[CN_SIDE][CN_SIDE])
   } list[CN_SIDE * CN_SIDE];	/* doesn't really need to be this big */
   Ssector *sect;
 
-  for(x = 1; x < CN_SIDE-1; x++)
-  for(y = 1; y < CN_SIDE-1; y++){
-    tx = x - (CN_VIEW+1) + ap->pos.x;	/* translate ary */
-    ty = y - (CN_VIEW+1) + ap->pos.y;	/* coords to map */
-    sect = &world.map[(*wrapx)(tx,ty)][(*wrapy)(tx,ty)];
-    ary[x][y].mvleft = -1;
-    ary[x][y].mvcost = get_army_move_cost(np,sect,ap);
+  for(x = 1; x < CN_SIDE-1; x++) {
+    for(y = 1; y < CN_SIDE-1; y++) {
+      tx = x - (CN_VIEW+1) + ap->pos.x;	/* translate ary */
+      ty = y - (CN_VIEW+1) + ap->pos.y;	/* coords to map */
+      sect = &world.map[(*wrapx)(tx,ty)][(*wrapy)(tx,ty)];
+      assert(x < CN_SIDE);
+      assert(y < CN_SIDE);
+      ary[x][y].mvleft = -1;
+      ary[x][y].mvcost = get_army_move_cost(np,sect,ap);
+    }
   }
  
-  for(i = 0;i < CN_SIDE * CN_SIDE;i++)	/* initialize list of points */
-  list[i].mv = 0;
+  for(i = 0;i < CN_SIDE * CN_SIDE;i++) { /* initialize list of points */
+    list[i].mv = 0;
+  }
  
   /* start army in center of ary with whatever movement it has */
   ary[CN_VIEW+1][CN_VIEW+1].mvleft = ap->mvpts;
@@ -398,32 +409,41 @@ void check_moves(Snation *np, Sarmy *ap, struct tmp_map ary[CN_SIDE][CN_SIDE])
   list[0].pos.y = CN_VIEW+1;
 
   for(head = 0; list[head].mv; head++){		/* until list is empty */
+    assert(head < CN_SIDE*CN_SIDE-1); /* make sure we're not going too far */
     mv = list[head].mv;
-    for(x = list[head].pos.x-1;x <= list[head].pos.x + 1;x++)
-      for(y = list[head].pos.y-1;y <= list[head].pos.y + 1;y++)
+    for(x = list[head].pos.x-1;x <= list[head].pos.x + 1;x++) {
+      for(y = list[head].pos.y-1;y <= list[head].pos.y + 1;y++) {
+        assert(x < CN_SIDE);
+        assert(y < CN_SIDE);
         if(ary[x][y].mvleft == -1 && ary[x][y].mvcost <= mv){
           mvleft = mv - ary[x][y].mvcost;
           ary[x][y].mvleft = mvleft;
           if(mvleft){
-            for(j = tail;list[j].mv < mvleft;j--);
-            for(k = tail;k > j;k--)
+            for(j = tail;list[j].mv < mvleft;j--) {
+              assert(j >= 0 && j < CN_SIDE*CN_SIDE);
+            }
+            for(k = tail;k > j;k--) {
+              assert(k+1 >= 0 && k+1 < CN_SIDE*CN_SIDE);
               list[k+1] = list[k];
+            }
             list[j+1].mv = mvleft;
             list[j+1].pos.x = x;
             list[j+1].pos.y = y;
             tail++;
           }
         }
+      }
     }
+  }
 
-/* if(debug){
-  printf("ary for army %d= :\n",ap->id);
-  for(y = 0; y < CN_SIDE; y++){
-    for(x = 0;x < CN_SIDE;x++)
-      printf("[%d,%d],",ary[x][y].mvleft,ary[x][y].mvcost);
-    printf("\n");
+  if(debug){
+    printf("ary for army %d= :\n",ap->id);
+    for(y = 0; y < CN_SIDE; y++){
+      for(x = 0;x < CN_SIDE;x++)
+        printf("[%d,%d],",ary[x][y].mvleft,ary[x][y].mvcost);
+      printf("\n");
     }
-  } */
+  }
 }
 
 /*--------------------------do_cn_diplo()------------------------------------
@@ -487,8 +507,8 @@ void do_cn_diplo(Snation *np)
 	  dip_to++;
 	}
 
-      dip_to = max(dip_to, JIHAD);		/* stay in bounds */
-      dip_to = min(dip_to, TREATY);
+      dip_to = dom_max_int(dip_to, JIHAD); /* stay in bounds */
+      dip_to = dom_min_int(dip_to, TREATY);
   /*    if (debug >= 2) { */
 	printf("up = %d, down = %d, newto = %d\n",up,down,dip_to);
   /*   } */
