@@ -6,20 +6,7 @@
 #ifndef _COMMON_H
 #define _COMMON_H
 
-#ifdef STDC_HEADERS
-# include <string.h>
-#else
-# ifndef HAVE_STRCHR
-#  define strchr index
-#  define strrchr rindex
-# endif /* HAVE_STRCHR */
-#endif /* STDC_HEADERS */
-
-#ifdef HAVE_UNISTD_H
-/* # include <sys/types.h> */
-/* # include <unistd.h> */
-#endif
-
+#include <string.h>
 
 /* get the control char corresponding to char c; checking if c is
    lower case or upper before converting.  NOTE: will probably only
