@@ -34,7 +34,7 @@
 #include "misc.h"
 #include "cur_stuff.h"
 #include <stdio.h>
-/* #include <signal.h> */
+#include <unistd.h>
 
 extern Suser user;
 extern Sworld world;
