@@ -440,7 +440,7 @@ int get_unemployed(Snation *np)
   while (ptlist != NULL) {
     sp = &world.map[ptlist->pt.x][ptlist->pt.y];
         /* only people who are un-employed */
-    n += max(0, sp->n_people - n_workers(sp));
+    n += dom_max_int(0, sp->n_people - n_workers(sp));
     ptlist = ptlist->next;
   }
   return n;
@@ -473,7 +473,7 @@ int get_unemp_met(Snation *np)
     sp = &world.map[ptlist->pt.x][ptlist->pt.y];
     if (sp->designation == D_METAL_MINE) {
         /* only people who are un-employed */
-      n += max(0, sp->n_people - n_workers(sp));
+      n += dom_max_int(0, sp->n_people - n_workers(sp));
     }
     ptlist = ptlist->next;
   }
@@ -507,7 +507,7 @@ int get_unemp_jwl(Snation *np)
     sp = &world.map[ptlist->pt.x][ptlist->pt.y];
     if (sp->designation == D_JEWEL_MINE) {
         /* only people who are un-employed */
-      n += max(0, sp->n_people - n_workers(sp));
+      n += dom_max_int(0, sp->n_people - n_workers(sp));
     }
     ptlist = ptlist->next;
   }
@@ -541,7 +541,7 @@ int get_unemp_farm(Snation *np)
     sp = &world.map[ptlist->pt.x][ptlist->pt.y];
     if (sp->designation == D_FARM) {
         /* only people who are un-employed */
-      n += max(0, sp->n_people - n_workers(sp));
+      n += dom_max_int(0, sp->n_people - n_workers(sp));
     }
     ptlist = ptlist->next;
   }
@@ -765,7 +765,7 @@ int n_workers(Ssector *sp)
   int rtvl;
 
   rtvl = get_max_employed(sp);
-  rtvl = min(sp->n_people, rtvl);
+  rtvl = dom_min_int(sp->n_people, rtvl);
   return rtvl;
 
 }
@@ -775,7 +775,7 @@ int emp_desire(Snation *np, int x, int y)
 {
   Ssector *sp = &world.map[x][y];
 
-/*  unemployed = min(0, n_workers(sp) - sp->n_people); */
+/*  unemployed = dom_min_int(0, n_workers(sp) - sp->n_people); */
     /* what we return is the percentage of people employed */
   return sp->n_people ? (100*n_workers(sp))/sp->n_people : 100;
 }
