@@ -31,6 +31,7 @@
 #include <stdlib.h>
 #include <sys/types.h>
 #include <netinet/in.h>
+#include <unistd.h>
 
 #define IN_FILE_C
 #include "dominion.h"
@@ -149,7 +150,7 @@ void write_world(Sworld *wp, char fname[])
   char cmd[200];		/* for compression command */
 
   if (compressed_world) {
-    sprintf(cmd, "compress > %s.Z", fname);
+    sprintf(cmd, "gzip > %s.gz", fname);
     if ((fp = popen(cmd, "w")) == NULL) {
       printf("\r\ncannot open pipe <%s> for writing\r\n", cmd);
       clean_exit();
@@ -415,7 +416,7 @@ int check_compressed_world(char fname[])
   FILE *fopen(),*fp;
 
   strcpy(Zname, fname);
-  strcat(Zname, ".Z");		/* if .Z file exists, it must be compressed! */
+  strcat(Zname, ".gz");		/* if .gz file exists, it must be compressed! */
   if ((fp = fopen(Zname, "r")) != NULL) {
     fclose(fp);
     return 1;
