@@ -19,14 +19,16 @@
  * along with this software; see the file COPYING.  If not, write to
  * the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
  */
-#include "dominion.h"
-#include "misc.h"
-
 #include <stdio.h>
 #include <stdlib.h>
 #include <math.h>
+#include <sys/types.h>
 #include <signal.h>
-/* #include <time.h> */
+#include <time.h>
+#include <unistd.h>
+
+#include "dominion.h"
+#include "misc.h"
 
 #ifdef HAVE_LIMITS
 # include <limits.h>
@@ -843,7 +845,7 @@ void gen_metal(Sworld *wp, double metal_per, double metal_avg,
   if (info_flag == 3)
   {
     printf("There are %d sectors with metal\n",tot_sect);
-    max_met = min(max_met, 20);
+    max_met = dom_min_int(max_met, 20);
     for (i= 0 ; i < max_met  ; i++)
     {
       printf("There are %d sectors with %d metal\n",hashes[i],i);
@@ -862,7 +864,7 @@ void gen_metal(Sworld *wp, double metal_per, double metal_avg,
               (int)((1.0 - metal_per) * 100.0),metal_avg);
     fprintf(fp,"Total Metal %d over %d sectors with %d maximum\n",
             tot_met,tot_sect ,max_met);
-    max_met = min(max_met, 20);
+    max_met = dom_min_int(max_met, 20);
     for (i= 0 ; i < max_met  ; i++)
     {
       fprintf(fp,"There are %d sectors with %d metal\n",hashes[i],i);
@@ -939,7 +941,7 @@ void gen_jewel(Sworld *wp, double jewel_per, double jewel_avg,
   if (info_flag == 3)
   {
     printf("There are %d sectors with jewels\n\n",tot_sect);
-    max_jewel = min(max_jewel, 20);
+    max_jewel = dom_min_int(max_jewel, 20);
     for (i= 0 ; i < max_jewel  ; i++)
     {
       printf("There are %d sectors with %d jewels\n",hashes[i],i);
@@ -960,7 +962,7 @@ void gen_jewel(Sworld *wp, double jewel_per, double jewel_avg,
                   (int)((1.0 - jewel_per) * 100.0),jewel_avg);
     fprintf(fp,"Total %d Jewels over %d sectors with %d max\n",
                tot_jewels, tot_sect, max_jewel);
-    max_jewel = min(max_jewel, 20);
+    max_jewel = dom_min_int(max_jewel, 20);
     for (i= 0 ; i < max_jewel  ; i++)
     {
       fprintf(fp,"There are %d sectors with %d jewels\n",hashes[i],i);
@@ -1091,7 +1093,7 @@ void gen_soil(Sworld *wp, double dim, double lac, double average,
   }
   if (info_flag == 3)
   {
-    max_s = min(max_s, 20);
+    max_s = dom_min_int(max_s, 20);
     for (i= 0 ; i < max_s  ; i++)
     {
       printf("There are %d sectors with %d soil\n",hashes[i],i);
@@ -1107,7 +1109,7 @@ void gen_soil(Sworld *wp, double dim, double lac, double average,
   if (fp != NULL)
   {
     fprintf(fp,"\nSoil Adjustment Factor %f Maximum is %d\n",average,max_s);
-    max_s = min(max_s, 20);
+    max_s = dom_min_int(max_s, 20);
     for (i= 0 ; i < max_s  ; i++)
     {
       fprintf(fp,"There are %d sectors with %d soil\n",hashes[i],i);
@@ -1232,7 +1234,7 @@ void set_compressed()
 int main(int argc, char *argv[])
 {
   extern char *optarg;
-  extern int optind;
+/*   extern int optind; */
   int i,j, percent, info_flag = 0, conf_flag;
   int c;
   double fracdim = -1.0,lacun = (2.0/3.0), perc_d, average;
