@@ -1,5 +1,4 @@
   /* menus.c -- various menus for dominion */
-
 /*
  * Copyright (C) 1990 Free Software Foundation, Inc.
  * Written by the dominion project.
@@ -372,7 +371,7 @@ void initiate_mage(Suser *up, WINDOW *w)
     statline(s, "initiate");
     move(LINES-1,strlen (s));
   }
-  if ((wget_name(w, name)) == NULL) {
+  if ((wget_name(w, name)) == 0) {
     strcpy(name, def_name);
   }
     /* if we got this far, it means that the initiation is valid */
@@ -392,7 +391,7 @@ void list_spells(Suser *up)
     spells = spells->next;
     ++n_spells;
   }
-  listw = newwin(n_spells+3, NAMELEN + 3, 2, 37);
+  listw = newwin(n_spells+3, NAMELEN + 3, 2, 32);
   box(listw, '|', '-');
   wstandout(listw);
   mvwaddstr(listw, 0, 2, "Spell");
@@ -565,37 +564,67 @@ void exec_initiate(char name[])
 void show_hanging_spells(Suser *up)
 {
   WINDOW *sw;
-  int done = 0, i;
-  Sh_spell *h_list;		/* list of hanging spells for this user */
-
+  int done = 0, i, army, xarg, yarg, j;
+  char *s2, line[EXECLEN];
+  Sh_spell *h_list, *top;	    /* list of hanging spells for this user */
   strcpy(help_tag, "Spells");
   statline("Hit space to get back", "show_hanging_spells");
-  sw = newwin(20, 30, 2, 2);
+  sw = newwin(20, 50, 2, 2);
+  h_list = up->h_spells;
+  j = 0;
   while (!done) {
-    mvwprintw(sw, 1, 1, "     Spell       thons");
+    mvwprintw(sw, 1, 1, "     Spell       Thons  Army    Sector ");
     wclrtobot(sw);
     if (up->id == 0) { waddstr(sw, " (nat)"); }
-    mvwprintw(sw, 2, 1, "   --------       --- ");
+    mvwprintw(sw, 2, 1, "   --------       ---   ----   --------");
     if (up->id == 0) { waddstr(sw, "  --- "); }
-    for (i = 0, h_list = up->h_spells; h_list != NULL;
+    for (i = 0, top = h_list; (h_list != NULL) && (i< 14) ;
 	 ++i,h_list = h_list->next) {
-      mvwprintw(sw, 3+i, 1, " %2d %-12.12s  %2d", i, h_list->name,
-		h_list->thons_left);
-      if (up->id == 0) { wprintw(sw, "    %3d", h_list->nat_id); }
+      strcpy (line,h_list->lines[0]);
+      s2 = strrchr(line, '_');
+      if ( s2 == NULL )
+	s2 = &line[0];
+      if (strncmp(s2+1, "SECTOR", strlen("SECTOR")) != 0) {
+        s2 = strchr(line, ':')+1;
+        sscanf(s2, "%d", &army);
+        mvwprintw(sw, 3+i, 1, " %2d %-12.12s  %2d   %4d            ", 
+		  i+(j*14), h_list->name,h_list->thons_left,army); }
+      else
+	{
+	fix_sector_line(line, s2);
+	s2 = strchr(s2, ':')+1;
+	sscanf(s2, "%d", &xarg);
+	s2 = strchr(s2, ':')+1;
+	sscanf(s2, "%d", &yarg);
+        mvwprintw(sw, 3+i, 1, " %2d %-12.12s  %2d          %4d %4d", i+(j*14), 
+		  h_list->name, h_list->thons_left,xarg,yarg); 
+        }
+
+      if (up->id == 0) { wprintw(sw, "  %3d", h_list->nat_id); }
       wclrtoeol(sw);
     }
-    mvwaddstr(sw, 18, 1, " [z]oom, [d]elete ");
+    mvwaddstr(sw, 18, 1, " [d]elete [n]ext page [t]op");
     wclrtoeol(sw);
     box(sw, '|', '-');
     wrefresh(sw);
     switch(mygetch()) {
-    case 'z':
-      zoom_on_h_spell(up->h_spells, sw);
-      break;
+    case 't':
+      h_list = up->h_spells;
+      j = 0;
+      break; 
     case 'd':
-      zoom_del_h_spell(up->h_spells, sw);
+      zoom_del_h_spell(up->h_spells, sw, up);
+      h_list = up->h_spells;
+      j = 0;
+      break;
+    case 'n':
+      if (h_list !=NULL)
+        {top=h_list;
+         j++;}
+      else
+	{h_list = up->h_spells;
+         j = 0;}
       break;
-
     case ' ':
       done = 1;
       break;
@@ -603,6 +632,7 @@ void show_hanging_spells(Suser *up)
       online_info();
       break;
     default:
+      h_list = top;
       break;
     }
   }
@@ -691,11 +721,12 @@ void fix_sector_line(char line[], char s[])
   /*    statline(s, "final s, hit space"); */
 }
 
-void zoom_del_h_spell(Sh_spell *h_list, WINDOW *sw)
+void zoom_del_h_spell (Sh_spell *h_list, WINDOW *sw, Suser *up)
 {
-  int n, i;
-
-    /* first ask the user which spell s/he wants to see */
+  int n, i, done = 0;
+  Sh_spell *prev,*temp;
+  prev = NULL;
+   /* first ask the user which spell s/he wants to see */
   mvwaddstr(sw, 18, 1, " Remove which spell? ");
   wclrtoeol(sw);
   box(sw, '|', '-');
@@ -704,13 +735,67 @@ void zoom_del_h_spell(Sh_spell *h_list, WINDOW *sw)
     return;
   }
   for (i = 0; h_list && i < n; ++i) {
-    h_list = h_list->next;
+     prev = h_list;
+     h_list = h_list->next;
+     if (h_list == NULL) {
+       return; }
   }
+  mvwprintw(sw, 18, 1, " Delete Spell #%d :%s (y/n)?", i,h_list->name);
+  wclrtoeol(sw);
+  box(sw, '|', '-');
+  wrefresh(sw);
+  switch(mygetch()) {
+    case 'y':
+    case 'Y':
+      break;
+    default: 
+      return;
+    }
+  temp = h_list;
+  if (prev != NULL)
+    {
+      h_list = up->h_spells;
+      for (i = 0; h_list && i < n && !done; ++i) {
+	 prev = h_list;
+	 h_list = h_list->next;
+	 if ( (temp->thons_left == h_list->thons_left) &&
+	     ( strcmp(temp->name,h_list->name) == 0) &&
+	     ( strcmp(temp->lines[0],h_list->lines[0]) == 0 ) )
+	   {done = 1; 
+	   }
+       }
+    }
   if (h_list == NULL) {
     return;
   }
-
-  delete_hanging_spell(h_list);
+    delete_hanging_spell(h_list); 
+  if (prev == NULL )
+    {
+      if ( h_list->next == NULL){
+         h_list = NULL;
+         up->h_spells = NULL;}
+      else{
+         h_list = h_list->next;
+         up->h_spells = h_list;}
+    }
+  else 
+    {
+      if (h_list->next == NULL){
+         prev->next = NULL;}
+      else{
+         prev->next = h_list->next;}
+      h_list = prev;
+    }
   return;
 }
 
+
+
+
+
+
+
+
+
+
+
