@@ -641,19 +641,17 @@ int free_army_id(Snation *np)
   return id;
 }
 
-#ifndef min
-min(a,b)
+int dom_min_int(a,b)
      int a,b;
 {
   return (a < b) ? a : b;
 }
 
-max(a,b)
+int dom_max_int(a,b)
      int a,b;
 {
   return (a > b) ? a : b;
 }
-#endif
 
 void statline(char s1[], char s2[]) /* print status line with s1 and s2 */
 {
