@@ -536,6 +536,7 @@ void cmd_cstrength(Snation *np, struct argument args[])
   if ((np->race.strength += args[1].data.num) < 1) {
     np->race.strength = 1;
   }
+    np->combat_bonus += args[1].data.num/2.5;
 }
 
   /* change the number of people in that sector */
@@ -665,12 +666,12 @@ void cmd_amerge(Snation *np, struct argument args[])
   ap = get_army(np, args[1].data.num);
   ap2 = get_army(np, args[2].data.num);
   sp = &world.map[ap->pos.x][ap->pos.y];
-  ap2->n_soldiers += ap->n_soldiers;
-  ap2->sp_bonus = min(ap->sp_bonus, ap2->sp_bonus);
-  ap2->mvpts = min(ap->mvpts, ap2->mvpts);
-  ap2->mvratio = min(ap->mvratio, ap2->mvratio);
-  delete_army_sector(sp, ap);
-  delete_army_nation(np, ap);
+  ap->n_soldiers += ap2->n_soldiers;
+  ap->sp_bonus = dom_min_int(ap2->sp_bonus, ap->sp_bonus);
+  ap->mvpts = dom_min_int(ap2->mvpts, ap->mvpts);
+  ap->mvratio = dom_min_int(ap2->mvratio, ap->mvratio);
+  delete_army_sector(sp, ap2);
+  delete_army_nation(np, ap2);
 }
 
   /* increases the army (of given id) by the given number of people */
