@@ -455,7 +455,7 @@ int spell_vampire_army(up, w, spellp, h_spellp)
 
   if (w) {
     mvwprintw(w, 4, 1,
-      "Cost: %d spell pts./100 sold.  Which army do you want to vampirize? ",
+      "Cost: %d spell pts./100 men.  Which army do you want to vampirize? ",
        spellp->cost);
     wrefresh(w);
   } else {
@@ -464,8 +464,12 @@ int spell_vampire_army(up, w, spellp, h_spellp)
   }
   if ( (wget_number(w, &id) <= 0) ||
        ((ap = get_army(up->np, id)) == NULL) ||
-      (ap->pos.x != up->cursor.x) || (ap->pos.y != up->cursor.y) ||
-      is_cargo(ap) ) {
+      (ap->pos.x != up->cursor.x) || (ap->pos.y != up->cursor.y)) {
+    return -1;
+  }
+  if (is_cargo(ap) || (!strcmp(ap->type, "Mage"))) {
+    statline2_err("(hit space to get back)",
+		  "Cannot Vampirize non-combatants.");
     return -1;
   }
   cost = (spellp->cost * ap->n_soldiers + 99)/100;
@@ -479,6 +483,7 @@ int spell_vampire_army(up, w, spellp, h_spellp)
 	  ap->id, AF_VAMPIRE);
   sprintf(h_spellp->lines[1], "AFLAG_CLEAR:%d:%d\n",
 	  ap->id, AF_VAMPIRE);
+  ap->jewel_maint+=1;
   return cost;
 }
 int spell_burrow_army(up, w, spellp, h_spellp)
