@@ -25,6 +25,7 @@
 #include "misc.h"
 #include <stdio.h>
 #include <math.h>
+#include <unistd.h>
 
 #include "army.h"
 #include "cur_stuff.h"
@@ -259,6 +260,7 @@ void transport_load(Sarmy *ap, WINDOW *tw)
 	  break;
 	}
 	ap->cargo.army = quantity;
+	loaded_army->status = A_DEFEND;
 	loaded_army->flags |= AF_IN_TRANSPORT;
 	aflag_set(loaded_army, AF_IN_TRANSPORT);
 	show_armies(sp);
