@@ -206,6 +206,7 @@ int main(int argc, char *argv[])
       if (np->cn_flag) {
 	cn_moves(np);		/* MDF: Put debug stuff here */
       }
+
       dotechno(np, mailfile);
       dospy(np, mailfile);
       domagic(np, mailfile);
@@ -214,7 +215,10 @@ int main(int argc, char *argv[])
       dojewels(np);
       dofood(np);
       docivilians(np);
-      if (mailfile) { fclose (mailfile); }
+      if (mailfile) {
+        fclose (mailfile);
+        mailfile = NULL;
+      }
     }
   }
   dobattles();
@@ -259,6 +263,7 @@ void update_send_mail()
     mailfile = fopen(mailname, "r");
     if (mailfile) {
       fclose (mailfile);
+      mailfile = NULL;
       sprintf(receiver,"%s of %s",
 	      world.nations[i].leader, world.nations[i].name);
       if (debug >= 2) {
@@ -443,7 +448,10 @@ void reset_armies()
 
       ap = next_ap;
     }
-    if (mailfile) { fclose(mailfile); }
+    if (mailfile) {
+      fclose(mailfile);
+      mailfile = NULL;
+    }
   }
   if (mfile) { fclose(mfile); }
 }
@@ -536,6 +544,7 @@ void take_sectors()
 	    }
 	    if (mailfile) {
 	      fclose(mailfile);
+              mailfile = NULL;
 	    }
 	    if (gets_mail(&world.nations[best->owner])) {
 	      sprintf(mailname, "mail%d", best->owner);
@@ -548,6 +557,7 @@ void take_sectors()
 		      xrel(j,i,world.nations[best->owner].capital),
 		      yrel(j,i,world.nations[best->owner].capital));
 	      fclose(mailfile);
+              mailfile = NULL;
 	    }
 	  }
 	  else if (debug >= 2) printf("They already own that sector!\n");
@@ -663,19 +673,19 @@ void take_capital(Snation *np1, Snation *np2, FILE *mfile)
 
   /* deplete nation */
   fprintf(sacker, "\nSacked capital of %s.  Gained:\n", np1->name);
-  fprintf(sacker, "\t%s\n\n", contents(max(np1->money/2, 0),
-				       max(np1->metal/2, 0),
-				       max(np1->jewels/2, 0),
-				       max(np1->food/2, 0), 0, -1, NULL, 0));
+  fprintf(sacker, "\t%s\n\n", contents(dom_max_int(np1->money/2, 0),
+				       dom_max_int(np1->metal/2, 0),
+				       dom_max_int(np1->jewels/2, 0),
+				       dom_max_int(np1->food/2, 0), 0, -1, NULL, 0));
   fclose (sacker);
 
-  np2->money += max(np1->money/2, 0); /* don't acquire debts */
+  np2->money += dom_max_int(np1->money/2, 0); /* don't acquire debts */
   np1->money = np1->money/2;
-  np2->jewels += max(np1->jewels/2, 0);
+  np2->jewels += dom_max_int(np1->jewels/2, 0);
   np1->jewels = np1->jewels/2;
-  np2->metal += max(np1->metal/2, 0);
+  np2->metal += dom_max_int(np1->metal/2, 0);
   np1->metal = np1->metal/2;
-  np2->food += max(np1->food/2, 0);
+  np2->food += dom_max_int(np1->food/2, 0);
   np1->food =np1->food/2;				      
 }
 
@@ -747,8 +757,8 @@ void movepeople(Snation *np, int a, int b, int x, int y)
   int p1, p2, moved, des1, des2;
 
   if ((a != x || b != y) && world.map[x][y].owner == world.map[a][b].owner) {
-/*    des1 = max(0,sect_desire(np, a, b));
-    des2 = max(0,sect_desire(np, x, y));
+/*    des1 = dom_max_int(0,sect_desire(np, a, b));
+    des2 = dom_max_int(0,sect_desire(np, x, y));
 */
       /* desireability = % of people employed */
     des1 = emp_desire(np, a, b);
@@ -757,7 +767,7 @@ void movepeople(Snation *np, int a, int b, int x, int y)
     p2 = world.map[x][y].n_people;
 
     moved = (p1*(100-des1))/400 - (p2*(100-des2))/400;
-    moved = min(moved, p1);
+    moved = dom_min_int(moved, p1);
       /* hold it!! we cannot move people underwater without bubbles */
     if (!good_altitude(&world.map[a][b], np)
 	|| !good_altitude(&world.map[x][y], np)) {
@@ -1315,8 +1325,9 @@ void move_people_free(Snation *np)
           if (world.map[xx][yy].n_people + work_data[xx][yy].moved > 0)
           {
 /* Then we move as many as we can, up to as many as we need */
-            moving = min(world.map[xx][yy].n_people + work_data[xx][yy].moved,
-                         -1 * world.map[x][y].n_people);
+            moving = dom_min_int(world.map[xx][yy].n_people
+				 + work_data[xx][yy].moved,
+				 -1 * world.map[x][y].n_people);
             world.map[xx][yy].n_people -= moving;
             world.map[x][y].n_people += moving;
 	  }
@@ -1352,6 +1363,8 @@ void fill_work_data(Snation *np)
     y = curr_pt->pt.y;
     sp = &(world.map[curr_pt->pt.x][curr_pt->pt.y]);
     work_data[x][y].des = get_max_employed(sp);
+    if (sp->designation == D_NODESIG)
+      work_data[x][y].des = 0.0;
 /* the adj holds the number of jobs available in that sector */
     work_data[x][y].adj = work_data[x][y].des - world.map[x][y].n_people;
     desire = (double)sect_desire(np,x,y);
@@ -1398,8 +1411,9 @@ void move_the_people(Snation *np)
           if (world.map[xx][yy].n_people + work_data[xx][yy].moved > 0)
           {
 /* Then we move as many as we can, up to as many as we need */
-            moving = min(world.map[xx][yy].n_people + work_data[xx][yy].moved,
-                         -1 * world.map[x][y].n_people);
+            moving = dom_min_int(world.map[xx][yy].n_people
+				 + work_data[xx][yy].moved,
+				 -1 * world.map[x][y].n_people);
             world.map[xx][yy].n_people -= moving;
             world.map[x][y].n_people += moving;
 	  }
